==> am_mod_evt_0_1.tar.gz: am_module_event/components/evt/template/barnraiser_01/edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
@import url(<?php echo $template_path_core;?>css/aroundme_calendar.css);
-->
</style>


<script language="JavaScript" src="<?php echo $template_path_core;?>js/imageHandling.js" type="text/javascript"></script>
<script type="text/javascript" src="<?php echo $template_path_core;?>js/calendar.js"></script>
<script type="text/javascript" src="<?php echo $template_path_core;?>js/calendar-setup.js"></script>



<form action="index.php?amn=evt_edit" method="post" name="frm" id="id_frm">
<?php if (isset($event['event_id']) && !empty($event['event_id'])) { ?>
<input type="hidden" name="event_id" value="<?php echo $event['event_id']; ?>" />
<?php } ?>
<div class="box">
	<div class="box_top">
		<?php echo $lang['hdr_edit_event']; ?><br />
	</div>
		
	<div class="box_mid">
		<div class="content">
			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<b><?php echo $lang['hdr_what']; ?></b><br />
						</p>
						
						<p>
							<label for="id_event_title"><?php echo $lang['txt_title'];?></label>
							<input id="id_event_title" class="input" type="text" name="event_title" size="24" value="<?php if (isset($event['event_title'])) { echo $event['event_title'];}?>" />
							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<label for="id_event_synopsis"><?php echo $lang['txt_synopsis'];?></label>
							<textarea id="id_event_synopsis" name="event_synopsis" cols="22" rows="2"><?php if (isset($event['event_synopsis'])) { echo $event['event_synopsis'];}?></textarea>
							<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=evt_event#synopsis');" />
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>

						<p>
							<b><?php echo $lang['hdr_where']; ?></b><br />
						</p>
						
						<?php
						if (isset($locations)) {
						?>
						<p>
						<label for="id_location"><?php echo $lang['txt_location'];?></label>
						<select id="id_location" name="location_id">
						<option value="0"><?php echo $lang['txt_location_none'];?></option>
							
						<?php
						foreach($locations as $key => $i):
						$selected="";
						if ($event['location_id'] == $i['location_id']) {
							$selected = " selected=\"selected\"";
						}
						?>
						<option value="<?php echo $i['location_id'];?>"<?php echo $selected;?>><?php echo $i['location_name'];?></option>
						<?php
						endforeach;
						?>
						</select>
						<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
						<br />	
						</p>
						<?php }?>
						
						<p>
							<label for="id_event_venue"><?php echo $lang['txt_venue'];?></label>
							<textarea id="id_event_venue" name="event_venue" cols="24" rows="2"><?php if (isset($event['event_venue'])) { echo $event['event_venue'];}?></textarea>
							<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=evt_event#venue');" />
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" />
					</td>
					<td valign="top" width="50%">
						<p>
							<b><?php echo $lang['hdr_when']; ?></b><br />
						</p>
						
						<script type="text/javascript">
						function setAllDay(id) {
							var displaystate = 'block';
							
							if (id.checked) {
								displaystate = 'none';
							}
							
							objShowHide('starttime', displaystate);
							objShowHide('duration', displaystate);
						}
						</script>
						
						<p>
							<label for="id_event_all_day"><?php echo $lang['txt_all_day_event'];?></label>
							<input type="checkbox" name="event_all_day" value="1" onChange="javascript:setAllDay(this);"<?php if (isset($event['event_start_time']) && $event['event_start_time'] == '00:00') { echo "checked=\"checked\""; } ?>/><br />
						</p>
						
						
						<label for="id_schedule_start_date"><?php echo $lang['txt_start_date'];?></label>
			  			<table border="0" cellspacing="1" cellpadding="0">
							<tr>
								<td>
			  						<input id="id_schedule_start_date" type="text" maxlength="10" class="input1" name="schedule_start_date" size="11" value="<?php if(isset($event['event_start_date'])) { echo $event['event_start_date'];} else echo date('Y-m-d'); ?>" /><br />
			  					</td>
								<td id="starttime">
									<input id="id_schedule_start_time" type="text" class="input1" maxlength="5" name="schedule_start_time" size="6" value="<?php if(isset($event['event_start_time'])) { echo $event['event_start_time'];}?>" /><br />
								</td>
			  					<td>
			  						
			  						<img src="<?php echo $template_path_core;?>img/cal_icon.png" id="id_cal_pop1" width="34" height="21" border="0" alt="" onmouseover="this.style.background='red';" onmouseout="this.style.background='';" />
			  						
			  						<script type="text/javascript">
			  							function dateChanged1(calendar) {
			  							
			  							 	if (calendar.dateClicked) { 
			  							   		var y = calendar.date.getFullYear();
			  							   		var m = calendar.date.getMonth()+1;     // integer, 0..11
			  							   		var d = calendar.date.getDate();      // integer, 1..31
			  									var h = calendar.date.getHours();      // integer, 1..31
			  									var i = calendar.date.getMinutes();      // integer, 1..31
			  							
			  							
			  									document.frm.id_schedule_start_date.value = y + '-' + m + '-' + d;
			  									document.frm.id_schedule_start_time.value = h + ':' + i;
			  									
			  									calendar.callCloseHandler();
			  							 	} 
			  							 	
			  							};
			  							
			  						  	Calendar.setup({           // our callback function
			  						        ifFormat       :    "%m-%d-%Y %k:%M",
			  								showsTime      :    true,
			  						        button         :    "id_cal_pop1",
			  						        singleClick    :    true,
			  						      	onSelect    : dateChanged1
			  						    });
			  						  	
			  						</script>
			  						
									</div>
									<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
									<br />
								</td>
							</tr>
						</table>
						
						<p id="duration">
							<label for="id_duration"><?php echo $lang['txt_duration'];?></label>
							<input id="id_duration" class="input1" type="text" name="event_duration" size="3" value="<?php if (isset($event['event_duration'])) echo $event['event_duration']; ?>"/>
							<select name="event_duration_type">
								<option value="1"<?php if (isset($event['event_duration_type']) && $event['event_duration_type'] == 1) echo " selected=\"selected\""?>><?php echo $lang['txt_hours']; ?></option>
								<option value="24"<?php if (isset($event['event_duration_type']) && $event['event_duration_type'] == 24) echo " selected=\"selected\""?>><?php echo $lang['txt_days']; ?></option>
							</select>
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<b><?php echo $lang['hdr_who']; ?></b><br />
						</p>
						
						<p>
							<label for="id_network"><?php echo $lang['txt_invite'];?></label>
							<select name="event_invite_type" style="width:180px;">
								<option value="1"<?php if (isset($event['event_invite_type']) && $event['event_invite_type'] == 1) echo "selected=\"selected\"";?>><?php echo $lang['txt_registered']; ?></option>
								<option value="2"<?php if (isset($event['event_invite_type']) && $event['event_invite_type'] == 2) echo "selected=\"selected\"";?>><?php echo $lang['txt_public']; ?></option>
							</select>
						</p>
						
						<p>
							<label for="id_event_allocation"><?php echo $lang['txt_allocation'];?></label>
							<input id="id_event_allocation" class="input" type="text" name="event_allocation" size="3" value="<?php if (isset($event['event_allocation'])) { echo $event['event_allocation'];}?>" />
							&nbsp;
							<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=evt_event#allocation');" />
							<br />
						</p>
					</td>
				</tr>
			</table>
			
			<hr />
			
			<p>
			<table border="0" height="100" cellpadding="0">
				<tr>
					<td>
						<label><?php echo $lang['txt_picture']; ?></label>
						<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
						<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
							<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($event['file_id']) && $event['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
							?>
						<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
							<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view']."\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
							?>
						</select>
					</td>
					<td>
						<?php echo $img_divs;?>
					</td>
				</tr>
				<tr>
					<label for="participation_type"><?php echo $lang['hdr_participation']; ?></label>
					<select style="width:150px;" id="id_participation_type" name="participation_type" onchange="showMembershipTypes(this);">
					<?php foreach($event_config['type'] as $key => $t): ?>
						<?php
							$selected = "";
							if (isset($_REQUEST['participation_type']) && $_REQUEST['participation_type'] == $t) {
								$selected = "selected=\"selected\"";
							}
						?>
						<option value="<?php echo $t; ?>"<?php echo $selected; ?>><?php echo $lang['event_type'][$t]; ?></option>
					<?php endforeach; ?>
					</select>
					
					<script type="text/javascript">
							function showMembershipTypes(id) {
								var displaystate = 'none';
		
								if (id.value == 4) {
									displaystate = 'block';
								}
								objShowHide('id_membership_type', displaystate);
							}
					</script>
					
					<p id="id_membership_type">
						<?php
						if (isset($lang['membership_type'])) {
						foreach ($lang['membership_type'] as $key => $i):
						
						$selected = "";
					
						if (!empty($event['membership_type_ids'])) {					
							foreach ($event['membership_type_ids'] as $keymt => $mt):
								if ($mt['membership_type_id'] == $key) {
									$selected = "checked=\"checked\"";
									break;
								}
							endforeach;
						}
						
						?>
						<label></label>
						<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
						<?php
						endforeach;
						}
						?>
					</p>
				
				<script type="text/javascript">
					var id = document.getElementById('id_participation_type');
					showMembershipTypes(id);
				</script>
					
					
				</tr>
			</table>
			<br />
			</p>
			
			<p>
				<label for="id_event_body"><?php echo $lang['txt_body'];?></label>
				<textarea id="id_event_body" name="event_body" cols="62" rows="6"><?php if (isset($event['event_body'])) { echo $event['event_body'];}?></textarea>
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=evt_event#details');" />
				<br />			
			</p>
			
			<p align="center">
				<?php echo $lang['txt_details']; ?>&nbsp;
				<input type="checkbox" name="event_private" <?php if (isset($_REQUEST['event_private']) && !empty($_REQUEST['event_private'])) echo "checked=\"checked\""; ?>/><br />	
			</p>

			<hr />
						
			<p align="right">
				<input type="submit" name="sub_preview" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				<input type="submit" name="sub_insert" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_edit'];?>" />
			</p>
			<?php
			if (isset($event_preview)) {
			?>
			<hr />
			<p><?php echo $event_preview['event_body']; ?></p>
			<?php } ?>
		</div>
	</div>
</div>

<div class="box_bottom">
	<span class="box_bottom_right"></span>
	<span class="box_bottom_left"></span>
</div>


</form>

==> am_mod_evt_0_3.tar.gz: am_module_event/components/evt/template/barnraiser_01/edit.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
@import url(<?php echo $template_path_core;?>css/aroundme_calendar.css);
-->
</style>


<script language="JavaScript" src="<?php echo $template_path_core;?>js/imageHandling.js" type="text/javascript"></script>
<script type="text/javascript" src="<?php echo $template_path_core;?>js/calendar.js"></script>
<script type="text/javascript" src="<?php echo $template_path_core;?>js/calendar-setup.js"></script>



<form action="index.php?amn=evt_edit" method="post" name="frm" id="id_frm">
<?php if (isset($event['event_id']) && !empty($event['event_id'])) { ?>
<input type="hidden" name="event_id" value="<?php echo $event['event_id']; ?>" />
<?php } ?>
<div class="box">
	<div class="box_top">
		<div class="content">
			<?php echo $lang['hdr_edit_event']; ?><br />
		</div>
	</div>
		
	<div class="box_mid">
		<div class="content">
			<table cellspacing="0" cellpadding="0" border="0">
				<tr>
					<td valign="top" width="50%">
						<p>
							<b><?php echo $lang['hdr_what']; ?></b><br />
						</p>
						
						<p>
							<label for="id_event_title"><?php echo $lang['txt_title'];?></label>
							<input id="id_event_title" class="input" type="text" name="event_title" size="24" value="<?php if (isset($event['event_title'])) { echo $event['event_title'];}?>" />
							&nbsp;<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<label for="id_event_synopsis"><?php echo $lang['txt_synopsis'];?></label>
							<textarea id="id_event_synopsis" name="event_synopsis" cols="22" rows="2"><?php if (isset($event['event_synopsis'])) { echo $event['event_synopsis'];}?></textarea>
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>

						<p>
							<b><?php echo $lang['hdr_where']; ?></b><br />
						</p>
						
						<?php
						if (isset($locations)) {
						?>
						<p>
						<label for="id_location"><?php echo $lang['txt_location'];?></label>
						<select id="id_location" name="location_id">
						<option value="0"><?php echo $lang['txt_location_none'];?></option>
							
						<?php
						foreach($locations as $key => $i):
						$selected="";
						if ($event['location_id'] == $i['location_id']) {
							$selected = " selected=\"selected\"";
						}
						?>
						<option value="<?php echo $i['location_id'];?>"<?php echo $selected;?>><?php echo $i['location_name'];?></option>
						<?php
						endforeach;
						?>
						</select>
						<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
						<br />	
						</p>
						<?php }?>
						
						<p>
							<label for="id_event_venue"><?php echo $lang['txt_venue'];?></label>
							<textarea id="id_event_venue" name="event_venue" cols="24" rows="2"><?php if (isset($event['event_venue'])) { echo $event['event_venue'];}?></textarea>
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
					</td>
					<td>
						<img src="<?php echo $template_path_core;?>img/pixel.png" alt="" border="0" width="20" />
					</td>
					<td valign="top" width="50%">
						<p>
							<b><?php echo $lang['hdr_when']; ?></b><br />
						</p>
						
						<script type="text/javascript">
						function setAllDay(id) {
							var displaystate = 'block';
							
							if (id.checked) {
								displaystate = 'none';
							}
							
							objShowHide('starttime', displaystate);
							objShowHide('duration', displaystate);
						}
						</script>
						
						<p>
							<label for="id_event_all_day"><?php echo $lang['txt_all_day_event'];?></label>
							<input type="checkbox" name="event_all_day" value="1" onChange="javascript:setAllDay(this);"<?php if (isset($event['event_start_time']) && $event['event_start_time'] == '00:00') { echo "checked=\"checked\""; } ?>/><br />
						</p>
						
						
						<label for="id_schedule_start_date"><?php echo $lang['txt_start_date'];?></label>
			  			<table border="0" cellspacing="1" cellpadding="0">
							<tr>
								<td>
			  						<input id="id_schedule_start_date" type="text" maxlength="10" class="input1" name="schedule_start_date" size="11" value="<?php if(isset($event['event_start_date'])) { echo $event['event_start_date'];} else echo date('Y-m-d'); ?>" /><br />
			  					</td>
								<td id="starttime">
									<input id="id_schedule_start_time" type="text" class="input1" maxlength="5" name="schedule_start_time" size="6" value="<?php if(isset($event['event_start_time'])) { echo $event['event_start_time'];} else echo date('H:i'); ?>" /><br />
								</td>
			  					<td>
			  						
			  						<img src="<?php echo $template_path_core;?>img/cal_icon.png" id="id_cal_pop1" border="0" alt="" onmouseover="this.style.background='red';" onmouseout="this.style.background='';" />
			  						
			  						<script type="text/javascript">
			  							function dateChanged1(calendar) {
			  							
			  							 	if (calendar.dateClicked) { 
			  							   		var y = calendar.date.getFullYear();
			  							   		var m = calendar.date.getMonth()+1;     // integer, 0..11
			  							   		var d = calendar.date.getDate();      // integer, 1..31
			  									var h = calendar.date.getHours();      // integer, 1..31
			  									var i = calendar.date.getMinutes();      // integer, 1..31
			  							
			  							
			  									document.frm.id_schedule_start_date.value = y + '-' + m + '-' + d;
			  									document.frm.id_schedule_start_time.value = h + ':' + i;
			  									
			  									calendar.callCloseHandler();
			  							 	} 
			  							 	
			  							};
			  							
			  						  	Calendar.setup({           // our callback function
			  						        ifFormat       :    "%m-%d-%Y %k:%M",
			  								showsTime      :    true,
			  						        button         :    "id_cal_pop1",
			  						        singleClick    :    true,
			  						      	onSelect    : dateChanged1
			  						    });
			  						  	
			  						</script>
			  						
									</div>
									<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
									<br />
								</td>
							</tr>
						</table>
						
						<p id="duration">
							<label for="id_duration"><?php echo $lang['txt_duration'];?></label>
							<input id="id_duration" class="input1" type="text" name="event_duration" size="3" value="<?php if (isset($event['event_duration'])) echo $event['event_duration']; else echo 1;?>"/>
							<select name="event_duration_type">
								<option value="1"<?php if (isset($event['event_duration_type']) && $event['event_duration_type'] == 1) echo " selected=\"selected\""?>><?php echo $lang['txt_hours']; ?></option>
								<option value="24"<?php if (isset($event['event_duration_type']) && $event['event_duration_type'] == 24) echo " selected=\"selected\""?>><?php echo $lang['txt_days']; ?></option>
							</select>
							<span style="cursor:default;" title="<?php echo $lang['txt_required'];?>">*</span>
							<br />
						</p>
						
						<p>
							<b><?php echo $lang['hdr_who']; ?></b><br />
						</p>
						
						<p>
							<label for="id_network"><?php echo $lang['txt_invite'];?></label>
							<select name="event_invite_type" style="width:180px;">
								<option value="1"<?php if (isset($event['event_invite_type']) && $event['event_invite_type'] == 1) echo "selected=\"selected\"";?>><?php echo $lang['txt_registered']; ?></option>
								<option value="2"<?php if (isset($event['event_invite_type']) && $event['event_invite_type'] == 2) echo "selected=\"selected\"";?>><?php echo $lang['txt_public']; ?></option>
							</select>
						</p>
						
						<p>
							<label for="id_event_allocation"><?php echo $lang['txt_allocation'];?></label>
							<input id="id_event_allocation" class="input" type="text" name="event_allocation" size="3" value="<?php if (isset($event['event_allocation'])) { echo $event['event_allocation'];}?>" />
							&nbsp;
							<br />
						</p>
					</td>
				</tr>
			</table>
			
			<hr />
			
			<p>
			<table border="0" height="100" cellpadding="0">
				<tr>
					<td>
						<label><?php echo $lang['txt_picture']; ?></label>
						<select style="width:150px;" id="id_file_id" size=3 name="file_id" onChange='javascript:setimg(this)'>
						<option value="0" selected="selected"><?php echo $lang['txt_none'];?></option>
							<?php
								$img_divs = "";
								foreach($images as $key => $i):
								$display_state = "none";
								$selected = "";
								if (isset($event['file_id']) && $event['file_id'] == $i['file_id']) {
									$selected = "selected=\"selected\"";
									$display_state = "block";
								}
							?>
						<option value="<?php echo $i['file_id'];?>" <?php echo $selected;?>><?php echo $i['file_save_name'];?></option>
							<?php
								$img_divs .= "<div style=\"display:" . $display_state . ";\" id=img" . $i['file_id'] . "><img src=\"get_file.php?file=" . $i['file_md5_name_view']."\" border=\"0\" class=\"picture\" /></div>";
								endforeach;
							?>
						</select>
					</td>
					<td>
						<?php echo $img_divs;?>
					</td>
				</tr>
				<tr>
					<td>
						<label for="participation_type"><?php echo $lang['hdr_participation']; ?></label>
						<?php
						// if this is set to membership type and we do not have permission to change this
						// we just print out that
						if (isset($event['event_type']) && $event['event_type'] == $event_config['type']['membership_type'] && $_SESSION['user_core_permission'] ^ $core_config['resource']['user']['mem_visible']) {
							echo $lang['event_type'][$event['event_type']];
							if (!empty($event['membership_type_ids'])) {
								$prnt = "<br /><i>(";
								foreach ($event['membership_type_ids'] as $keymt => $mt):
									$prnt .= $lang['membership_type'][$mt['membership_type_id']] . ", ";
								endforeach;
	
								$prnt = substr ($prnt, 0, -2) . ")</i><br />";
								echo $prnt;
							}
						}
						else {
						?>
						<select style="width:150px;" id="id_participation_type" name="participation_type" onchange="showMembershipTypes(this);">
						<?php
						foreach($event_config['type'] as $key => $t): 

						// check to see if we are allowed to set membership types
						if ($t == $event_config['type']['membership_type'] && $_SESSION['user_core_permission'] ^ $core_config['resource']['user']['mem_visible']) {
							break;
						}
						?>
							<?php
								$selected = "";
								if (isset($_REQUEST['participation_type']) && $_REQUEST['participation_type'] == $t) {
									$selected = "selected=\"selected\"";
								}
							?>
							<option value="<?php echo $t; ?>"<?php echo $selected; ?>><?php echo $lang['event_type'][$t]; ?></option>
						<?php endforeach; ?>
						</select>
						<?php }?>

						<?php
						if ($_SESSION['user_core_permission'] & $core_config['resource']['user']['mem_visible']) {
						?>
						<script type="text/javascript">
								function showMembershipTypes(id) {
									var displaystate = 'none';
		
									if (id.value == 4) {
										displaystate = 'block';
									}
									objShowHide('id_membership_type', displaystate);
								}
						</script>
					
						<p id="id_membership_type">
							<?php
							if (isset($lang['membership_type'])) {
							foreach ($lang['membership_type'] as $key => $i):
							
							$selected = "";
					
							if (!empty($event['membership_type_ids'])) {					
								foreach ($event['membership_type_ids'] as $keymt => $mt):
									if ($mt['membership_type_id'] == $key) {
										$selected = "checked=\"checked\"";
										break;
									}
								endforeach;
							}
							
							?>
							<label></label>
							<input type="checkbox" name="membership_types[]" value="<?php echo $key;?>" <?php echo $selected;?> />&nbsp;<?php echo $i;?><br />
							<?php
							endforeach;
							}
							?>
						</p>
				
						<script type="text/javascript">
							var id = document.getElementById('id_participation_type');
							showMembershipTypes(id);
						</script>
						<?php }?>
					
					</td>
				</tr>
				<?php if (!isset($_REQUEST['event_id'])) { ?>
					<label for="identity_id"><?php echo $lang['txt_my_identity']; ?></label>
					<select name="identity_id">
						<?php foreach($identities as $i): ?>
							<?php 
								$selected = '';
								if (!empty($_REQUEST['identity_id'])) {
									if ($i['identity_id'] == $_REQUEST['identity_id']) {
										$selected = "selected=\"selected\"";
									}
								}
							?>
							<option value="<?php echo $i['identity_id']; ?>" <?php echo $selected; ?>><?php echo $i['identity_name']; ?></option>
						<?php endforeach; ?>
					</select>
				<?php  } ?>
			</table>
			<br />
			</p>
			
			<p>
				<label for="id_event_body"><?php echo $lang['txt_body'];?></label>
				<textarea id="id_event_body" name="event_body" cols="62" rows="6" style="width: 480px;"><?php if (isset($event['event_body'])) { echo $event['event_body'];}?></textarea>
				<br />			
			</p>
			
			<p align="center">
				<?php echo $lang['txt_details']; ?>&nbsp;
				<input type="checkbox" name="event_private" <?php if (isset($_REQUEST['event_private']) && !empty($_REQUEST['event_private'])) echo "checked=\"checked\""; ?>/><br />	
			</p>

			<hr />
						
			<p align="right">
				<input type="submit" name="sub_preview" id="id_sub_preview" class="input_submit" value="<?php echo $lang['sub_preview']; ?>" />
				<?php
				if (isset($allow_spellcheck)) {
				?>
				<input type="button" class="input_submit" value="<?php echo $lang['sub_check_spelling'];?>" onClick="openSpellChecker();" />
				<?php }?>
				<input type="submit" name="sub_insert" id="id_sub_insert" class="input_submit" value="<?php echo $lang['sub_edit'];?>" />
			</p>
			<?php
			if (isset($event_preview)) {
			?>
			<hr />
			<p><?php echo $event_preview['event_body']; ?></p>
			<?php } ?>
		</div>
	</div>
</div>
</form>
